@@ -1,5 +1,10 @@
 from airflow.models.connection import Connection
 from airflow.models.dagbag import DagBag
+from dagster import (
+    Definitions,
+    _check as check,
+)
+
 from dagster_airflow.dagster_pipeline_factory import (
     DagsterAirflowError,
     _create_airflow_connections,
@@ -8,9 +13,6 @@ from dagster_airflow.dagster_pipeline_factory import (
     patch_airflow_example_dag,
 )
 
-from dagster import Definitions
-from dagster import _check as check
-
 
 def make_dagster_job_from_airflow_dag(
     dag,
@@ -102,7 +104,6 @@ def make_dagster_definitions_from_airflow_dag_bag(
     """Construct a Dagster definition corresponding to Airflow DAGs in DagBag.
 
     Usage:
-
         Create `make_dagster_definition.py`:
             from dagster_airflow import make_dagster_definition_from_airflow_dag_bag
             from airflow_home import my_dag_bag
@@ -125,10 +126,10 @@ def make_dagster_definitions_from_airflow_dag_bag(
             database for each run. (default: False)
         connections (List[Connection]): List of Airflow Connections to be created in the Ephemeral
             Airflow DB, if use_emphemeral_airflow_db is False this will be ignored.
+
     Returns:
         Definitions
     """
-
     schedules, jobs = _make_schedules_and_jobs_from_airflow_dag_bag(
         dag_bag,
         use_airflow_template_context,
