@@ -2,9 +2,10 @@ import os
 
 import dateutil.parser
 from airflow.exceptions import AirflowException, AirflowSkipException
-
-from dagster import DagsterEventType
-from dagster import _check as check
+from dagster import (
+    DagsterEventType,
+    _check as check,
+)
 from dagster._core.events import DagsterEvent
 from dagster._core.execution.api import create_execution_plan, execute_plan
 from dagster._core.execution.plan.plan import can_isolate_steps, should_skip_step
